@@ -19,7 +19,7 @@ using Kerfuffle::Archive;
 
 namespace Kerfuffle
 {
-    class Query;
+class Query;
 }
 
 /**
@@ -29,21 +29,21 @@ namespace Kerfuffle
  * and for determining data displaying order in part's view.
  */
 enum EntryMetaDataType {
-    DisplayName,         /**< The entry's name that will be displayed in the view */
-    Size,                /**< The entry's original size */
-    CompressedSize,      /**< The compressed size for the entry */
-    Permissions,         /**< The entry's permissions */
-    Owner,               /**< The user the entry belongs to */
-    Group,               /**< The user group the entry belongs to */
-    Ratio,               /**< The compression ratio for the entry */
-    CRC,                 /**< The entry's CRC */
-    BLAKE2,              /**< The entry's BLAKE2 */
-    Method,              /**< The compression method used on the entry */
-    Version,             /**< The archiver version needed to extract the entry */
-    Timestamp            /**< The timestamp for the current entry */
+    DisplayName, /**< The entry's name that will be displayed in the view */
+    Size, /**< The entry's original size */
+    CompressedSize, /**< The compressed size for the entry */
+    Permissions, /**< The entry's permissions */
+    Owner, /**< The user the entry belongs to */
+    Group, /**< The user group the entry belongs to */
+    Ratio, /**< The compression ratio for the entry */
+    CRC, /**< The entry's CRC */
+    BLAKE2, /**< The entry's BLAKE2 */
+    Method, /**< The compression method used on the entry */
+    Version, /**< The archiver version needed to extract the entry */
+    Timestamp /**< The timestamp for the current entry */
 };
 
-class ArchiveModel: public QAbstractItemModel
+class ArchiveModel : public QAbstractItemModel
 {
     Q_OBJECT
 public:
@@ -52,23 +52,21 @@ public:
 
     QVariant data(const QModelIndex &index, int role) const override;
     Qt::ItemFlags flags(const QModelIndex &index) const override;
-    QVariant headerData(int section, Qt::Orientation orientation,
-                        int role = Qt::DisplayRole) const override;
-    QModelIndex index(int row, int column,
-                      const QModelIndex &parent = QModelIndex()) const override;
+    QVariant headerData(int section, Qt::Orientation orientation, int role = Qt::DisplayRole) const override;
+    QModelIndex index(int row, int column, const QModelIndex &parent = QModelIndex()) const override;
     QModelIndex parent(const QModelIndex &index) const override;
     int rowCount(const QModelIndex &parent = QModelIndex()) const override;
     int columnCount(const QModelIndex &parent = QModelIndex()) const override;
 
-    //drag and drop related
+    // drag and drop related
     Qt::DropActions supportedDropActions() const override;
     QStringList mimeTypes() const override;
-    QMimeData *mimeData(const QModelIndexList & indexes) const override;
-    bool dropMimeData(const QMimeData * data, Qt::DropAction action, int row, int column, const QModelIndex & parent) override;
+    QMimeData *mimeData(const QModelIndexList &indexes) const override;
+    bool dropMimeData(const QMimeData *data, Qt::DropAction action, int row, int column, const QModelIndex &parent) override;
 
     void reset();
     void createEmptyArchive(const QString &path, const QString &mimeType, QObject *parent);
-    Kerfuffle::LoadJob* loadArchive(const QString &path, const QString &mimeType, QObject *parent);
+    Kerfuffle::LoadJob *loadArchive(const QString &path, const QString &mimeType, QObject *parent);
     Kerfuffle::Archive *archive() const;
 
     QList<int> shownColumns() const;
@@ -76,17 +74,24 @@ public:
 
     Archive::Entry *entryForIndex(const QModelIndex &index);
 
-    Kerfuffle::ExtractJob* extractFile(Archive::Entry *file, const QString& destinationDir, Kerfuffle::ExtractionOptions options = Kerfuffle::ExtractionOptions()) const;
-    Kerfuffle::ExtractJob* extractFiles(const QVector<Archive::Entry*>& files, const QString& destinationDir, Kerfuffle::ExtractionOptions options = Kerfuffle::ExtractionOptions()) const;
+    Kerfuffle::ExtractJob *
+    extractFile(Archive::Entry *file, const QString &destinationDir, Kerfuffle::ExtractionOptions options = Kerfuffle::ExtractionOptions()) const;
+    Kerfuffle::ExtractJob *extractFiles(const QList<Archive::Entry *> &files,
+                                        const QString &destinationDir,
+                                        Kerfuffle::ExtractionOptions options = Kerfuffle::ExtractionOptions()) const;
 
-    Kerfuffle::PreviewJob* preview(Archive::Entry *file) const;
-    Kerfuffle::OpenJob* open(Archive::Entry *file) const;
-    Kerfuffle::OpenWithJob* openWith(Archive::Entry *file) const;
+    Kerfuffle::PreviewJob *preview(Archive::Entry *file) const;
+    Kerfuffle::OpenJob *open(Archive::Entry *file) const;
+    Kerfuffle::OpenWithJob *openWith(Archive::Entry *file) const;
 
-    Kerfuffle::AddJob* addFiles(QVector<Archive::Entry*> &entries, const Archive::Entry *destination, const Kerfuffle::CompressionOptions& options = Kerfuffle::CompressionOptions());
-    Kerfuffle::MoveJob* moveFiles(QVector<Archive::Entry*> &entries, Archive::Entry *destination, const Kerfuffle::CompressionOptions& options = Kerfuffle::CompressionOptions());
-    Kerfuffle::CopyJob* copyFiles(QVector<Archive::Entry*> &entries, Archive::Entry *destination, const Kerfuffle::CompressionOptions& options = Kerfuffle::CompressionOptions());
-    Kerfuffle::DeleteJob* deleteFiles(QVector<Archive::Entry*> entries);
+    Kerfuffle::AddJob *addFiles(QList<Archive::Entry *> &entries,
+                                const Archive::Entry *destination,
+                                const Kerfuffle::CompressionOptions &options = Kerfuffle::CompressionOptions());
+    Kerfuffle::MoveJob *
+    moveFiles(QList<Archive::Entry *> &entries, Archive::Entry *destination, const Kerfuffle::CompressionOptions &options = Kerfuffle::CompressionOptions());
+    Kerfuffle::CopyJob *
+    copyFiles(QList<Archive::Entry *> &entries, Archive::Entry *destination, const Kerfuffle::CompressionOptions &options = Kerfuffle::CompressionOptions());
+    Kerfuffle::DeleteJob *deleteFiles(QList<Archive::Entry *> entries);
 
     /**
      * @param password The password to encrypt the archive with.
@@ -113,27 +118,27 @@ public:
      * entries for both new and existing paths, the method will return false. Also, if merging is not allowed,
      * this method will return false for entries with the same path and types.
      */
-    bool conflictingEntries(QList<const Archive::Entry*> &conflictingEntries, const QStringList &entries, bool allowMerging) const;
+    bool conflictingEntries(QList<const Archive::Entry *> &conflictingEntries, const QStringList &entries, bool allowMerging) const;
 
     static bool hasDuplicatedEntries(const QStringList &entries);
 
-    static QMap<QString, Archive::Entry*> entryMap(const QVector<Archive::Entry*> &entries);
+    static QMap<QString, Archive::Entry *> entryMap(const QList<Archive::Entry *> &entries);
 
-    QMap<QString, Kerfuffle::Archive::Entry*> filesToMove;
-    QMap<QString, Kerfuffle::Archive::Entry*> filesToCopy;
+    QMap<QString, Kerfuffle::Archive::Entry *> filesToMove;
+    QMap<QString, Kerfuffle::Archive::Entry *> filesToCopy;
 
 Q_SIGNALS:
     void loadingStarted();
     void loadingFinished(KJob *);
-    void error(const QString& error, const QString& details);
-    void droppedFiles(const QStringList& files, const Archive::Entry*);
-    void messageWidget(KMessageWidget::MessageType type, const QString& msg);
+    void error(const QString &error, const QString &details);
+    void droppedFiles(const QStringList &files, const Archive::Entry *);
+    void messageWidget(KMessageWidget::MessageType type, const QString &msg);
 
 private Q_SLOTS:
     void slotNewEntry(Archive::Entry *entry);
     void slotListEntry(Archive::Entry *entry);
     void slotLoadingFinished(KJob *job);
-    void slotEntryRemoved(const QString & path);
+    void slotEntryRemoved(const QString &path);
     void slotUserQuery(Kerfuffle::Query *query);
     void slotCleanupEmptyDirs();
 
@@ -147,7 +152,7 @@ private:
      *
      * @return @p fileName without the leading './'
      */
-    QString cleanFileName(const QString& fileName);
+    QString cleanFileName(const QString &fileName);
 
     void initRootEntry();
 
